@@ -319,35 +319,40 @@ def sendmail(job, subject, text, attachments, log):
         if not data and target and os.path.exists(target):
             data=open(target, 'rb').read(attachment_size)
 
-        if data:
-            if len(data)>attachment_gzip:
-                log.info('gzip attachment %s', filename)
-                file_out=StringIO.StringIO()
-                zfile=gzip.GzipFile(filename, 'wb', 9, file_out)
-                if maintype=='text':
-                    # all txt gzip file are encode in UTF8 to avoid the loose of the charset 
-                    data=data.decode(charset).encode('utf-8')
-                zfile.write(data)
-                zfile.close()
-                data=file_out.getvalue()
-                file_out.close()
-                filename+='.gz'
-                maintype, subtype='application', 'x-gzip'
+        if data==None:
+            data=''
 
-            if len(data)>attachment_size:
-                log.warning('attachment %s too big, file skipped', filename)
-                continue
-
-            #maintype, subtype = 'application', 'octet-stream'
+        if len(data)>attachment_gzip:
+            log.info('gzip attachment %s', filename)
+            file_out=StringIO.StringIO()
+            zfile=gzip.GzipFile(filename, 'wb', 9, file_out)
             if maintype=='text':
-                attachment=MIMEText(data, subtype, charset)
-            else:
-                attachment=MIMEBase(maintype, subtype)
-                attachment.set_payload(data) #, charset) #dont use the charset, here !
-                email.Encoders.encode_base64(attachment)
-    
-            attachment.add_header('Content-Disposition', 'attachment', filename=filename)
-            msg.attach(attachment)
+                # all txt gzip file are encode in UTF8 to avoid the loose of the charset 
+                data=data.decode(charset).encode('utf-8')
+            zfile.write(data)
+            zfile.close()
+            data=file_out.getvalue()
+            file_out.close()
+            filename+='.gz'
+            maintype, subtype='application', 'x-gzip'
+
+        if len(data)>attachment_size:
+            log.warning('attachment is too big, skipped: %s', filename)
+            # replace attachment by an "error"
+            data='attachment is too big: %s\n' % (filename, )
+            filename=os.path.splitext(filename)[0]+'-error.txt'
+            maintype, subtype, charset='text', 'plain', 'ascii'
+            
+        #maintype, subtype = 'application', 'octet-stream'
+        if maintype=='text':
+            attachment=MIMEText(data, subtype, charset)
+        else:
+            attachment=MIMEBase(maintype, subtype)
+            attachment.set_payload(data) #, charset) #dont use the charset, here !
+            email.Encoders.encode_base64(attachment)
+
+        attachment.add_header('Content-Disposition', 'attachment', filename=filename)
+        msg.attach(attachment)
     
     body=msg.as_string()
 
