@@ -19,7 +19,7 @@ from archiver import *
 import ftpd
 import cron
 
-GHETTO_VERSION='2011_03_14_1'
+GHETTO_VERSION=[ '2011_03_14_1', '2011_06_28_1' ] 
 
 exit_code_re=re.compile('^\s*exit_code\s*=\s*([0-9]+)\s*$')
 
@@ -311,7 +311,7 @@ class Ghettovcb(Archiver):
                 if self.ghettovcb_wait_nfs:
                     log.debug('this version of ghettovcb wait before to unmount the NFS share')
                 
-                if self.ghettovcb_version!=GHETTO_VERSION:
+                if not self.ghettovcb_version in GHETTO_VERSION:
                     warnings['local']='This version of ghettoVCB.sh (%s) script has not been tested with MKSBackup, be warned ! Check the download page for more.' % (self.ghettovcb_version, )
                 
             # read and extract global_conf
@@ -678,16 +678,23 @@ class Ghettovcb(Archiver):
             self.upload_status+='upload_dst-%s=%s\r\n' % (current_vm, target)
             
             filenames=set()
-            finished=False
+            finished=False # ghettoVCB is still working on the current_vm
+            wait=60
             while not finished:
+                
+                print 'ASX WAIT', wait
+                while wait>0 and not finished:
+                    time.sleep(1)
+                    wait-=1
+                    finished=current_vm in self.finished_vm
+                wait=60 # for next time
+                                    
                 # get epoch from ESX(i)
-                time.sleep(15)
                 exit_code, output=RunCommand(self.t, 'date +%s', log=None)
                 if exit_code:
                     self.log.error('cannot get epoch: %r', output)
                     return False
 
-                finished=current_vm in self.finished_vm
                 # print 'ASX finished', current_vm, finished
                 esx_epoch=int(output.split('\n')[0])
                 exit_code, output=RunCommand(self.t, find_cmd, log=None)
@@ -735,7 +742,6 @@ class Ghettovcb(Archiver):
 
                     source=filename
                                 
-                    self.uploaded_filenames[line]=None
                     if compressed:
                         relfilename='%s.tar.gz' % (current_vm, )
                     else:
@@ -764,9 +770,15 @@ class Ghettovcb(Archiver):
                         exit_code, output=RunCommand(self.t, ftp_line, log=None)
                         if exit_code==0:
                             self.log.debug('file uploaded: %s', destination)
+                            self.uploaded_filenames[line]=None
                         else:
-                            status='ERR'
-                            self.log.error('upload failed %s (%s)', destination, output)
+                            if finished:
+                                status='ERR'
+                                self.log.error('upload failed %s (%s)', destination, output)
+                                self.log.debug('epoch=%d file=%s', esx_epoch, line)
+                            else:
+                                self.log.info('upload failed, retry later %s (%s)', destination, output)
+                                
                     elif protocol=='ssh':
                         dest_dir=os.path.join(target, posixpath.dirname(destination))
                         try:
@@ -788,8 +800,13 @@ class Ghettovcb(Archiver):
                                 self.log.debug('scp %s %s', scp_source, destination)
                                 scpclient.get(source, destination)
                             except scp.SCPException, e:
-                                self.log.error('download failed: %s (%s)', destination, e)
-                                status='ERR'
+                                if finished:
+                                    status='ERR'
+                                    self.log.error('download failed: %s (%s)', destination, e)
+                                    self.log.debug('epoch=%d file=%s', esx_epoch, line)
+                                else:
+                                    self.log.info('download failed, retry later %s (%s)', destination, e)
+                        
                         else:
                             # use local SCP
                             scp_args=self.scp_args[:]
@@ -806,8 +823,19 @@ class Ghettovcb(Archiver):
                                 self.log.debug('copying %s: %s', source, scp_err)
         
                             if scp_process.returncode!=0:
-                                self.log.error('download failed: %s (%s)', destination, scp_out+scp_err)
-                                status='ERR'
+                                if finished:
+                                    status='ERR'
+                                    self.log.error('download failed: %s (%s)', destination, scp_out+scp_err)
+                                    self.log.debug('epoch=%d file=%s', esx_epoch, line)
+                                else:
+                                    self.log.info('download failed, retry later %s (%s)', destination, scp_out+scp_err)
+                    
+                    if not finished:
+                        # reload the list to work on fresh data
+                        wait=1 
+                        break
+                    
+
 
             end=time.time()                
             if status!='OK':
